package com.hzya.frame.nifiapi.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author：liuyang
 * @Package：com.hzya.frame.nifiapi.util
 * @Project：fw-nifi
 * @name：NifiFilterUtil
 * @Date：2025/5/23 14:45
 * @Filename：NifiFilterUtil
 */
@Component
public class NifiFilterUtil {

    Logger logger = LoggerFactory.getLogger(NifiFilterUtil.class);

    /**
     * 过滤端口列表，保留 comments 包含指定 mark 的端口
     *
     * @param ports    端口列表（InputPorts 或 OutputPorts）
     * @param mark     过滤关键字
     * @param portType 端口类型（用于日志）
     * @param <T>      端口类型（InputPorts 或 OutputPorts）
     * @return 过滤后的端口列表
     */
    public <T> List<T> filterPortsByComments(List<T> ports, String mark, String portType) {
//        if (ports == null || mark == null) {
//            logger.debug("未提供｛｝或标记，返回空列表", portType);
//            return Collections.emptyList();
//        }

        if (ports == null || mark == null) {
            return ports;
        }

        return ports.stream()
                .filter(port -> hasMatchingComments(port, mark))
                .collect(Collectors.toList());
    }

    /**
     * 检查端口的 comments 是否包含指定 mark
     *
     * @param port 端口对象
     * @param mark 过滤关键字
     * @return 是否匹配
     */
    private boolean hasMatchingComments(Object port, String mark) {
        try {
            // 假设 InputPorts 和 OutputPorts 有 getComponent 方法
            Object component = port.getClass().getMethod("getComponent").invoke(port);
            if (component == null) {
                return false;
            }
            String comments = (String) component.getClass().getMethod("getComments").invoke(component);
            return comments != null && comments.contains(mark);
        } catch (Exception e) {
            logger.error("访问comments出错: {}", port, e);
            return false;
        }
    }
}
